changeset 85811:cd42bdedadb3

(delsel-unload-hook): Remove function and variable. (delsel-unload-function): New-style unload function, adapted from `delsel-unload-hook'.
author Juanma Barranquero <lekktu@gmail.com>
date Wed, 31 Oct 2007 00:30:54 +0000
parents 0ab0355c4c17
children 9555d3db1fbb
files lisp/delsel.el
diffstat 1 files changed, 10 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/delsel.el	Wed Oct 31 00:30:09 2007 +0000
+++ b/lisp/delsel.el	Wed Oct 31 00:30:54 2007 +0000
@@ -35,7 +35,7 @@
 
 ;; Commands which will delete the selection need a 'delete-selection
 ;; property on their symbols; commands which insert text but don't
 ;; have this property won't delete the selction.  It can be one of
 ;; the values:
 ;;  'yank
 ;;      For commands which do a yank; ensures the region about to be
@@ -147,14 +147,19 @@
 (define-key minibuffer-local-must-match-map "\C-g" 'minibuffer-keyboard-quit)
 (define-key minibuffer-local-isearch-map "\C-g" 'minibuffer-keyboard-quit)
 
-(defun delsel-unload-hook ()
+(defun delsel-unload-function ()
+  "Unload the Delete Selection library."
   (define-key minibuffer-local-map "\C-g" 'abort-recursive-edit)
   (define-key minibuffer-local-ns-map "\C-g" 'abort-recursive-edit)
   (define-key minibuffer-local-completion-map "\C-g" 'abort-recursive-edit)
   (define-key minibuffer-local-must-match-map "\C-g" 'abort-recursive-edit)
-  (define-key minibuffer-local-isearch-map "\C-g" 'abort-recursive-edit))
-
-(add-hook 'delsel-unload-hook 'delsel-unload-hook)
+  (define-key minibuffer-local-isearch-map "\C-g" 'abort-recursive-edit)
+  (dolist (sym '(self-insert-command self-insert-iso yank clipboard-yank
+		 insert-register delete-backward-char backward-delete-char-untabify
+		 delete-char newline-and-indent newline open-line))
+    (remprop sym 'delete-selection))
+  ;; continue standard unloading
+  nil)
 
 (provide 'delsel)
@@ -35,7 +35,7 @@
 ;; Commands which will delete the selection need a 'delete-selection
 ;; property on their symbols; commands which insert text but don't
-;; have this property won't delete the selction.  It can be one of
+;; have this property won't delete the selection.  It can be one of
 ;; the values:
 ;;  'yank